
import { useEffect, useState, useRef } from "react";
import { useLocation, Link } from "react-router-dom";
import Navigation from "@/components/Navigation";
import HeroSection from "@/components/HeroSection";
import FeatureCard from "@/components/FeatureCard";
import { Button } from "@/components/ui/button";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Badge } from "@/components/ui/badge";
import { useIntersectionObserver, scrollToElement } from "@/lib/animations";
import { ArrowUp, Clock } from "lucide-react";
import SEO from "@/components/SEO";
import OptimizedImage from "@/components/OptimizedImage";

const Index = () => {
  const location = useLocation();
  const [showScrollTop, setShowScrollTop] = useState(false);
  
  // Extension URL
  const extensionUrl = "https://chromewebstore.google.com/detail/click-n-test-hacker-mode/adgpinopckdedhegddlhnafnkmojmkih";
  
  useEffect(() => {
    // Check if we have a section to scroll to from navigation
    if (location.state && location.state.scrollToId) {
      setTimeout(() => {
        scrollToElement(location.state.scrollToId);
      }, 100);
    }
    
    // Add scroll event listener for the scroll-to-top button
    const handleScroll = () => {
      if (window.scrollY > 300) {
        setShowScrollTop(true);
      } else {
        setShowScrollTop(false);
      }
    };
    
    window.addEventListener('scroll', handleScroll);
    return () => {
      window.removeEventListener('scroll', handleScroll);
    };
  }, [location]);

  // Blog posts data for the landing page
  const featuredBlogs = [
    {
      title: 'Click n Test vs Bug Magnet: The Ultimate Comparison',
      excerpt: 'Discover why modern testers are making the switch to more efficient testing tools. We compare features, usability, and performance to help you choose the best tool for your testing workflow.',
      readTime: '5 min read',
      slug: 'click-n-test-vs-bug-magnet-comparison',
      tags: ['Testing Tools', 'Comparison']
    },
    {
      title: 'Essential Software Testing Tools Every QA Professional Should Know',
      excerpt: 'A comprehensive guide to the most important testing tools for 2024. From automated testing frameworks to manual testing aids, learn about the tools that can transform your QA process.',
      readTime: '8 min read',
      slug: 'essential-software-testing-tools-2024',
      tags: ['QA Tools', 'Best Practices']
    },
    {
      title: 'Complete Guide to Exploratory Testing Tools',
      excerpt: 'Master exploratory testing with the right tools and techniques. Learn how to conduct effective exploratory testing sessions and discover bugs that automated tests might miss.',
      readTime: '15 min read',
      slug: 'complete-guide-exploratory-testing-tools',
      tags: ['Exploratory Testing', 'Techniques']
    }
  ];

  return (
    <>
      <SEO 
        title="Click 'n Test - Tester Mode | Ultimate Software Testing Extension"
        description="Ultimate Chrome extension for software testers. Insert test data quickly with right-click. Alternative to Bug Magnet & Click N Click."
        keywords="software testing, test data, chrome extension, bug magnet alternative, click n click, testing tools, QA tools"
        url="https://clickntest.sqatesting.com/"
      />
      
      <div className="min-h-screen flex flex-col">
        <Navigation />
        
        <main id="main-content">
          {/* Hero Section */}
          <HeroSection />
          
          {/* Features Section */}
          <section 
            id="features" 
            className="section relative overflow-hidden bg-hacker-dark"
            aria-labelledby="features-heading"
          >
            <div className="container mx-auto px-4">
              <SectionHeader 
                title="Powerful Features" 
                subtitle="Tester Focused" 
                description="Built by Testers for developers to solve real testing problems." 
              />
              
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 mt-16">
                <FeatureCard title="Quick Test Data Insertion" description="Insert various types of test data with a simple right-click in any input field." color="#00FFFF" icon={<LightningIcon />} delay={100} />
                
                <FeatureCard title="Rich Data Categories" description="Access text content, personal info, contact details, financial data, dates, and much more." color="#9D00FF" icon={<DatabaseIcon />} delay={200} />
                
                <FeatureCard title="Easy to Use" description="Intuitive right-click context menu makes inserting test data quick and effortless." color="#00FF66" icon={<CheckIcon />} delay={300} />
                
                <FeatureCard title="Customizable" description="Edit the config.json file to add your own custom test data categories and values." color="#FF00FF" icon={<SettingsIcon />} delay={400} />
                
                <FeatureCard title="Lightweight" description="Minimal impact on browser performance while providing powerful functionality." color="#00FFFF" icon={<SpeedIcon />} delay={500} />
                
                <FeatureCard title="Tester Focused" description="Built by Testers for developers to solve real testing problems." color="#00FF66" icon={<CodeIcon />} delay={600} />
              </div>
            </div>
            
            {/* Background decorations */}
            <div className="absolute -right-20 -bottom-20 w-80 h-80 bg-gradient-radial from-neon-purple/20 to-transparent rounded-full blur-3xl" aria-hidden="true" />
            <div className="absolute -left-20 top-40 w-80 h-80 bg-gradient-radial from-neon-blue/10 to-transparent rounded-full blur-3xl" aria-hidden="true" />
          </section>
          
          {/* Installation Section */}
          <section 
            id="installation" 
            className="section bg-hacker-light relative overflow-hidden"
            aria-labelledby="installation-heading"
          >
            <div className="container mx-auto px-4">
              <SectionHeader title="Installation" subtitle="Get Started in Seconds" description="Installing Click 'n Test - Hacker Mode is quick and straightforward." />
              
              <div className="max-w-4xl mx-auto mt-16">
                <div className="bg-hacker-dark rounded-lg p-6 border border-neon-blue/20 shadow-lg">
                  <h3 id="installation-heading" className="font-bold text-2xl mb-6 text-center">Install from Chrome Web Store</h3>
                  
                  <div className="flex flex-col md:flex-row gap-8 items-center">
                    <div className="flex-1">
                      <ol className="list-decimal list-inside space-y-4 text-gray-300">
                        <li className="pb-4 border-b border-gray-700">
                          <a 
                            href={extensionUrl} 
                            className="text-neon-blue hover:underline focus:outline-none focus:ring-2 focus:ring-neon-blue rounded" 
                            target="_blank" 
                            rel="noopener noreferrer" 
                            aria-label="Visit Click N Test Chrome Web Store page (opens in new tab)"
                          >
                            Visit Click N Test Extension on Chrome Web Store
                          </a>
                        </li>
                        <li className="pb-4 border-b border-gray-700">
                          Click the "Add to Chrome" button
                        </li>
                        <li className="pb-4 border-b border-gray-700">
                          Confirm the installation when prompted
                        </li>
                        <li>
                          Once installed, you'll see the extension icon in your browser toolbar
                        </li>
                      </ol>
                      
                      <div className="mt-8">
                        <Button 
                          className="bg-gradient-to-r from-neon-blue to-neon-purple hover:opacity-90 text-black font-medium w-full" 
                          onClick={() => window.open(extensionUrl, "_blank", "noopener,noreferrer")}
                          aria-label="Get Click 'n Test from Chrome Web Store (opens in new tab)"
                        >
                          Get Click 'n Test Extension from Chrome Web Store
                        </Button>
                      </div>
                    </div>
                    
                    <div className="flex-1">
                      <div className="rounded-lg overflow-hidden border border-gray-700 shadow-xl">
                        <OptimizedImage 
                          src="https://images.unsplash.com/photo-1461749280684-dccba630e2f6?w=500&h=300&fit=crop&crop=center" 
                          alt="Chrome extension installation interface showing browser settings and add-on management" 
                          width={500} 
                          height={300}
                          className="w-full h-auto"
                          loading="lazy"
                        />
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            
            {/* Background decorations */}
            <div className="absolute -right-10 top-20 w-60 h-60 bg-gradient-radial from-neon-green/10 to-transparent rounded-full blur-3xl" aria-hidden="true" />
          </section>
          
          {/* Usage Section */}
          <section 
            id="usage" 
            className="section bg-hacker-dark relative overflow-hidden"
            aria-labelledby="usage-heading"
          >
            <div className="container mx-auto px-4">
              <SectionHeader title="Usage Guide" subtitle="How to Use Click 'n Test" description="Learn how to use Click 'n Test to streamline your development and testing workflow." />
              
              <div className="max-w-5xl mx-auto mt-16">
                <Tabs defaultValue="basic" className="w-full">
                  <TabsList className="grid grid-cols-3 mb-8" role="tablist">
                    <TabsTrigger value="basic" role="tab" aria-controls="basic-panel">Basic Usage</TabsTrigger>
                    <TabsTrigger value="advanced" role="tab" aria-controls="advanced-panel">Advanced Features</TabsTrigger>
                    <TabsTrigger value="custom" role="tab" aria-controls="custom-panel">Customization</TabsTrigger>
                  </TabsList>
                  
                  <TabsContent value="basic" className="border border-gray-700 rounded-lg p-6 bg-hacker-light" role="tabpanel" id="basic-panel">
                    <div className="flex flex-col lg:flex-row gap-8">
                      <div className="flex-1">
                        <h3 id="usage-heading" className="text-2xl font-bold mb-4 text-neon-blue">Basic Usage</h3>
                        
                        <ol className="list-decimal list-inside space-y-4 text-gray-300">
                          <li className="pb-3">
                            <span className="font-medium text-white">Right-click in any text input field</span>
                            <p className="text-gray-400 mt-1">Works with standard HTML inputs, textareas, and content-editable elements</p>
                          </li>
                          <li className="pb-3">
                            <span className="font-medium text-white">Navigate to the "Click 'n Test" menu</span>
                            <p className="text-gray-400 mt-1">You'll find it in the context menu that appears when you right-click</p>
                          </li>
                          <li className="pb-3">
                            <span className="font-medium text-white">Select the desired test data category</span>
                            <p className="text-gray-400 mt-1">Choose from various data types like names, emails, addresses, etc.</p>
                          </li>
                          <li>
                            <span className="font-medium text-white">The selected text will be inserted</span>
                            <p className="text-gray-400 mt-1">Text appears at the cursor position or replaces the current selection</p>
                          </li>
                        </ol>
                      </div>
                      
                      <div className="flex-1">
                        <div className="rounded-lg overflow-hidden border border-gray-700 shadow-xl">
                          <OptimizedImage 
                            src="https://images.unsplash.com/photo-1486312338219-ce68d2c6f44d?w=500&h=300&fit=crop&crop=center" 
                            alt="Developer using testing tools on a MacBook Pro showing context menu functionality" 
                            width={500} 
                            height={300}
                            className="w-full h-full object-cover"
                            loading="lazy"
                          />
                        </div>
                      </div>
                    </div>
                  </TabsContent>
                  
                  <TabsContent value="advanced" className="border border-gray-700 rounded-lg p-6 bg-hacker-light" role="tabpanel" id="advanced-panel">
                    <div className="flex flex-col lg:flex-row gap-8">
                      <div className="flex-1">
                        <h3 className="text-2xl font-bold mb-4 text-neon-purple">Advanced Features</h3>
                        
                        <div className="text-center py-12">
                          <div className="inline-block p-6 bg-hacker-dark/50 rounded-xl border border-neon-purple/30">
                            <h4 className="text-neon-purple text-xl mb-3">Coming Soon</h4>
                            <p className="text-gray-300">Advanced features are under development and will be available in a future update.</p>
                          </div>
                        </div>
                      </div>
                      
                      <div className="flex-1">
                        <div className="rounded-lg overflow-hidden border border-gray-700 shadow-xl h-full">
                          <OptimizedImage 
                            src="https://images.unsplash.com/photo-1518770660439-4636190af475?w=500&h=300&fit=crop&crop=center" 
                            alt="Advanced software development workspace with multiple monitors and circuit board technology" 
                            width={500} 
                            height={300}
                            className="w-full h-full object-cover opacity-50"
                            loading="lazy"
                          />
                        </div>
                      </div>
                    </div>
                  </TabsContent>
                  
                  <TabsContent value="custom" className="border border-gray-700 rounded-lg p-6 bg-hacker-light" role="tabpanel" id="custom-panel">
                    <div className="flex flex-col lg:flex-row gap-8">
                      <div className="flex-1">
                        <h3 className="text-2xl font-bold mb-4 text-neon-green">Customization</h3>
                        
                        <div className="text-center py-12">
                          <div className="inline-block p-6 bg-hacker-dark/50 rounded-xl border border-neon-green/30">
                            <h4 className="text-neon-green text-xl mb-3">Coming Soon</h4>
                            <p className="text-gray-300">Customization features are under development and will be available in a future update.</p>
                          </div>
                        </div>
                      </div>
                      
                      <div className="flex-1">
                        <div className="rounded-lg overflow-hidden border border-gray-700 shadow-xl h-full">
                          <pre className="bg-hacker-dark text-neon-green p-4 font-mono text-sm overflow-auto h-full opacity-50" aria-label="Example configuration JSON code">
                          {`{
  "categories": [
    {
      "name": "Custom Templates",
      "values": [
        {
          "name": "User Profile",
          "value": {
            "name": "John Doe",
            "email": "john@example.com",
            "phone": "555-123-4567"
          }
        },
        {
          "name": "Product Data",
          "value": {
            "id": "PROD-12345",
            "name": "Widget Pro",
            "price": "$99.99"
          }
        }
      ]
    }
  ]
}`}
                          </pre>
                        </div>
                      </div>
                    </div>
                  </TabsContent>
                </Tabs>
              </div>
            </div>
          </section>
          
          {/* Support Section */}
          <section 
            id="support" 
            className="section bg-hacker-light relative overflow-hidden"
            aria-labelledby="support-heading"
          >
            <div className="container mx-auto px-4">
              <SectionHeader title="Troubleshooting & Support" subtitle="Need Help?" description="Get assistance with common issues or reach out for support." />
              
              <div className="max-w-4xl mx-auto mt-16 grid grid-cols-1 md:grid-cols-2 gap-8">
                <div className="bg-hacker-dark rounded-lg p-6 border border-neon-blue/20 shadow-lg">
                  <h3 id="support-heading" className="text-xl font-bold mb-4 text-neon-blue">Common Issues</h3>
                  
                  <ul className="space-y-4">
                    <li className="pb-3 border-b border-gray-700">
                      <h4 className="font-medium text-white">Extension not appearing in context menu</h4>
                      <p className="text-gray-300 mt-1">Try reloading the extension from chrome://extensions/ or restart your browser</p>
                    </li>
                    <li className="pb-3 border-b border-gray-700">
                      <h4 className="font-medium text-white">Data not inserting correctly</h4>
                      <p className="text-gray-300 mt-1">Check if the field is editable and that you have proper permissions on the page</p>
                    </li>
                    <li>
                      <h4 className="font-medium text-white">Custom data not showing up</h4>
                      <p className="text-gray-300 mt-1">Verify your config.json format and reload the extension</p>
                    </li>
                  </ul>
                  
                  <Link to="/view-troubleshooting">
                    <Button 
                      variant="outline" 
                      className="mt-6 border-neon-blue text-neon-blue hover:bg-neon-blue/10 w-full"
                      aria-label="View detailed troubleshooting guide for Click 'n Test"
                    >
                      View Detailed Troubleshooting Guide
                    </Button>
                  </Link>
                </div>
                
                <div className="bg-hacker-dark rounded-lg p-6 border border-neon-purple/20 shadow-lg">
                  <h3 className="text-xl font-bold mb-4 text-neon-purple">Get Support</h3>
                  
                  <p className="text-gray-300 mb-6">
                    Need additional help? Check the console (F12) for any error messages, and reach out through our support team.
                  </p>
                  
                  <div className="flex justify-center">
                    <Link to="/contact">
                      <Button 
                        className="bg-gradient-to-r from-neon-blue to-neon-purple text-black"
                        aria-label="Contact Click 'n Test support team"
                      >
                        Contact Our Support Team
                      </Button>
                    </Link>
                  </div>
                </div>
              </div>
            </div>
            
            {/* Background decorations */}
            <div className="absolute right-20 top-40 w-60 h-60 bg-gradient-radial from-neon-purple/10 to-transparent rounded-full blur-3xl" aria-hidden="true" />
          </section>
          
          {/* Blog Section */}
          <section 
            id="blog" 
            className="section bg-hacker-dark relative overflow-hidden"
            aria-labelledby="blog-heading"
          >
            <div className="container mx-auto px-4">
              <SectionHeader 
                title="Latest Testing Insights" 
                subtitle="Learn & Improve" 
                description="Stay updated with the latest testing trends, tool comparisons, and best practices from the software testing community." 
              />
              
              <div className="max-w-6xl mx-auto mt-16">
                <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
                  {featuredBlogs.map((blog, index) => (
                    <article key={blog.slug} className="bg-hacker-light rounded-lg p-6 border border-gray-700 hover:border-neon-blue/50 transition-all duration-300 hover:transform hover:scale-105">
                      <div className="flex flex-wrap gap-2 mb-4">
                        {blog.tags.map(tag => (
                          <Badge key={tag} variant="outline">
                            {tag}
                          </Badge>
                        ))}
                      </div>
                      
                      <h3 className="text-xl font-bold text-white mb-3 line-clamp-2">
                        {blog.title}
                      </h3>
                      
                      <p className="text-gray-300 mb-4 line-clamp-3">
                        {blog.excerpt}
                      </p>
                      
                      <div className="flex items-center justify-between">
                        <span className="text-sm text-gray-400 flex items-center gap-1">
                          <Clock className="w-3 h-3" aria-hidden="true" />
                          {blog.readTime}
                        </span>
                        
                        <Link to={`/blog/${blog.slug}`}>
                          <Button 
                            variant="outline" 
                            size="sm" 
                            className="border-neon-blue text-neon-blue hover:bg-neon-blue/10"
                            aria-label={`Read more about ${blog.title}`}
                          >
                            Read Complete Article
                          </Button>
                        </Link>
                      </div>
                    </article>
                  ))}
                </div>
                
                <div className="text-center mt-12">
                  <Link to="/blog">
                    <Button 
                      className="bg-gradient-to-r from-neon-green to-neon-blue hover:opacity-90 text-black font-medium text-lg px-8 py-3"
                      aria-label="View all Click 'n Test blog articles"
                    >
                      View All Testing Articles
                    </Button>
                  </Link>
                </div>
              </div>
            </div>
            
            {/* Background decorations */}
            <div className="absolute -right-20 -bottom-20 w-80 h-80 bg-gradient-radial from-neon-purple/20 to-transparent rounded-full blur-3xl" aria-hidden="true" />
            <div className="absolute -left-20 top-40 w-80 h-80 bg-gradient-radial from-neon-blue/10 to-transparent rounded-full blur-3xl" aria-hidden="true" />
          </section>
          
          {/* CTA Section */}
          <section 
            className="py-24 bg-gradient-to-r from-hacker-dark to-hacker-light relative overflow-hidden"
            aria-labelledby="cta-heading"
          >
            <div className="container mx-auto px-4 text-center max-w-3xl relative z-10">
              <h2 id="cta-heading" className="text-4xl font-bold mb-6 text-gradient glow-text">
                Ready to Supercharge Your Testing?
              </h2>
              
              <p className="text-lg text-gray-300 mb-10">
                Join thousands of developers and testers who are saving time and boosting productivity with Click 'n Test - Tester Mode.
              </p>
              
              <Button 
                className="bg-gradient-to-r from-neon-blue via-neon-purple to-neon-green hover:opacity-90 text-black font-semibold text-lg px-8 py-6" 
                onClick={() => window.open(extensionUrl, "_blank", "noopener,noreferrer")}
                aria-label="Add Click 'n Test to Chrome - Free installation (opens in new tab)"
              >
                Add Click 'n Test to Chrome - Get Started Free
              </Button>
              
              <div className="mt-8 text-sm text-gray-400">
                Works with all Chromium-based browsers
              </div>
            </div>
            
            {/* Background decorations */}
            <div className="absolute inset-0 matrix-bg opacity-10" aria-hidden="true" />
            <div className="absolute left-10 bottom-10 w-80 h-80 bg-gradient-radial from-neon-blue/20 to-transparent rounded-full blur-3xl" aria-hidden="true" />
            <div className="absolute right-10 top-10 w-80 h-80 bg-gradient-radial from-neon-purple/20 to-transparent rounded-full blur-3xl" aria-hidden="true" />
          </section>
        </main>
        
        {/* Scroll to top button */}
        {showScrollTop && (
          <button 
            className="fixed bottom-8 right-8 p-3 rounded-full bg-neon-blue text-black shadow-lg hover:bg-neon-purple transition-colors duration-300 z-50 animate-fade-in focus:outline-none focus:ring-2 focus:ring-neon-blue focus:ring-offset-2 focus:ring-offset-hacker-dark"
            onClick={() => window.scrollTo({ top: 0, behavior: 'smooth' })}
            aria-label="Scroll to top of page"
            type="button"
          >
            <ArrowUp className="w-6 h-6" aria-hidden="true" />
          </button>
        )}
      </div>
    </>
  );
};

// Section Header Component
const SectionHeader = ({
  title,
  subtitle,
  description
}: {
  title: string;
  subtitle: string;
  description: string;
}) => {
  const {
    ref,
    isIntersecting
  } = useIntersectionObserver();
  const [isVisible, setIsVisible] = useState(false);
  useEffect(() => {
    if (isIntersecting) {
      setIsVisible(true);
    }
  }, [isIntersecting]);
  return <div ref={ref} className={`text-center max-w-3xl mx-auto transition-all duration-1000 ${isVisible ? 'opacity-100 translate-y-0' : 'opacity-0 translate-y-10'}`}>
      <div className="inline-block mb-2">
        <span className="bg-neon-blue/10 text-neon-blue text-sm font-medium py-1 px-3 rounded-full">
          {subtitle}
        </span>
      </div>
      
      <h2 className="text-3xl md:text-4xl font-bold mb-4 text-gradient glow-text">
        {title}
      </h2>
      
      <p className="text-gray-400 text-lg">
        {description}
      </p>
    </div>;
};

// Icons
const LightningIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13 10V3L4 14h7v7l9-11h-7z" />
  </svg>;
const DatabaseIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4 7v10c0 2.21 3.582 4 8 4s8-1.79 8-4V7M4 7c0 2.21 3.582-4 8-4s8 1.79 8 4m0 5c0 2.21-3.582 4-8 4s-8-1.79-8-4" />
  </svg>;
const CheckIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
  </svg>;
const SettingsIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M10.325 4.317c.426-1.756 2.924-1.756 3.35 0a1.724 1.724 0 002.573 1.066c1.543-.94 3.31.826 2.37 2.37a1.724 1.724 0 001.065 2.572c1.756.426 1.756 2.924 0 3.35a1.724 1.724 0 00-1.066 2.573c.94 1.543-.826 3.31-2.37 2.37a1.724 1.724 0 00-2.572 1.065c-.426 1.756-2.924 1.756-3.35 0a1.724 1.724 0 00-2.573-1.066c-1.543.94-3.31-.826-2.37-2.37a1.724 1.724 0 00-1.065-2.572c-1.756-.426-1.756-2.924 0-3.35a1.724 1.724 0 001.066-2.573c-.94-1.543.826-3.31 2.37-2.37.996.608 2.296.07 2.572-1.065z" />
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
  </svg>;
const SpeedIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13 10V3L4 14h7v7l9-11h-7z" />
  </svg>;
const CodeIcon = () => <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-6 h-6">
    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M8 9l3 3-3 3m5 0h3M5 20h14a2 2 0 002-2V6a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
  </svg>;

export default Index;
